@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
 
 1;
 
@@ -14,13 +14,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 DESCRIPTION
 
@@ -118,6 +120,8 @@ L<https://github.com/maxmind/GeoIP2-perl/issues>.
 If you are having an issue with a MaxMind service that is not specific to the
 client API please see L<http://www.maxmind.com/en/support> for details.
 
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -142,7 +146,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack E. Choroba Florian Ragwitz Graham Knop Mateu X Hunter
+=for stopwords Andy Jack E. Choroba Florian Ragwitz Graham Knop Mateu X Hunter Narsimham Chelluri
 
 =over 4
 
@@ -166,11 +170,15 @@ Graham Knop <haarg@haarg.org>
 
 Mateu X Hunter <mhunter@maxmind.com>
 
+=item *
+
+Narsimham Chelluri <nchelluri@users.noreply.github.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
