@@ -3,7 +3,10 @@ package GeoIP2::Database::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
+
+use Moo;
+use namespace::autoclean;
 
 use Data::Validate::IP 0.24
     qw( is_ipv4 is_ipv6 is_private_ipv4 is_private_ipv6 );
@@ -20,8 +23,6 @@ use GeoIP2::Model::ISP;
 use GeoIP2::Types qw( Str );
 use MaxMind::DB::Reader 1.000000;
 
-use Moo;
-
 with 'GeoIP2::Role::HasLocales';
 
 has file => (
@@ -149,7 +150,7 @@ sub enterprise {
     my $self = shift;
     return $self->_model_for_address(
         'Enterprise',
-        type_check => qr/^GeoIP2-Enterprise$/,
+        type_check => qr/^GeoIP2-(?:Precision-)?Enterprise$/,
         @_
     );
 }
@@ -182,13 +183,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -364,6 +367,10 @@ data each end point I<may> return.
 Every record class attribute has a corresponding predicate method so you can
 check to see if the attribute is set.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -388,7 +395,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
