@@ -3,11 +3,12 @@ package GeoIP2::Error::IPAddressNotFound;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
-
-use GeoIP2::Types qw( Str );
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
+
+use GeoIP2::Types qw( Str );
 
 extends 'Throwable::Error';
 
@@ -25,13 +26,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Error::IPAddressNotFound - An exception thrown when an IP address is not in the MaxMind GeoIP2 database
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -72,6 +75,10 @@ inherited from L<Throwable::Error>. It also provide two methods of its own:
 
 Returns the IP address that could not be found.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -96,7 +103,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
