@@ -3,9 +3,10 @@ package GeoIP2::Error::Type;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
 
 extends 'Throwable::Error';
 
@@ -29,13 +30,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Error::Type - A type validation error.
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -83,6 +86,10 @@ Returns the name of the type which failed validation.
 
 Returns the value which triggered the validation failure.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -107,7 +114,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
