@@ -3,11 +3,12 @@ package GeoIP2::Model::ConnectionType;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
-
-use GeoIP2::Types qw( IPAddress Str );
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
+
+use GeoIP2::Types qw( IPAddress Str );
 
 with 'GeoIP2::Role::Model::Flat', 'GeoIP2::Role::HasIPAddress';
 
@@ -25,13 +26,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Model::ConnectionType - Model class for the GeoIP2 Connection Type database
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -62,6 +65,10 @@ Returns the connection type as a string.
 
 Returns the IP address used in the lookup.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -86,7 +93,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
