@@ -3,15 +3,20 @@ package GeoIP2::Model::Country;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
+
+use Moo;
+use namespace::autoclean;
 
 use GeoIP2::Types qw( HashRef object_isa_type );
 use Sub::Quote qw( quote_sub );
 
-use Moo;
-
 with 'GeoIP2::Role::Model::Location';
 
+## no critic (ProhibitUnusedPrivateSubroutines)
+sub _has { has(@_) }
+## use critic
+
 __PACKAGE__->_define_attributes_for_keys(
     qw( continent country maxmind registered_country traits ));
 
@@ -23,13 +28,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Model::Country - Model class for the GeoIP2 Precision: Country and GeoIP2 Country
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -91,6 +98,10 @@ from the C<country> for things like military bases.
 Returns a L<GeoIP2::Record::Traits> object representing the traits for the
 requested IP address.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -115,7 +126,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
