@@ -3,9 +3,10 @@ package GeoIP2::Record::Country;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
 
 with 'GeoIP2::Role::Record::Country';
 
@@ -17,13 +18,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Record::Country - Contains data for the country record associated with an IP address
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -92,6 +95,10 @@ locale codes.
 
 This attribute is returned by all end points.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -116,7 +123,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
