@@ -3,11 +3,12 @@ package GeoIP2::Record::Postal;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
-
-use GeoIP2::Types qw( NonNegativeInt Str );
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
+
+use GeoIP2::Types qw( NonNegativeInt Str );
 
 has code => (
     is        => 'ro',
@@ -29,13 +30,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Record::Postal - Contains data for the postal code record associated with an IP address
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -79,6 +82,10 @@ postal code is correct.
 This attribute is only available from the Insights end point and the GeoIP2
 Enterprise database.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -103,7 +110,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
