@@ -3,11 +3,12 @@ package GeoIP2::Record::Subdivision;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
-
-use GeoIP2::Types qw( NonNegativeInt PositiveInt Str );
+our $VERSION = '2.003003';
 
 use Moo;
+use namespace::autoclean;
+
+use GeoIP2::Types qw( NonNegativeInt PositiveInt Str );
 
 with 'GeoIP2::Role::Record::HasNames';
 
@@ -37,13 +38,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::Record::Subdivision - Contains data for the subdivision record associated with an IP address
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -114,6 +117,10 @@ locale codes.
 
 This attribute is returned by all end points except the Country end point.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -138,7 +145,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
