@@ -5,7 +5,10 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.003002';
+our $VERSION = '2.003003';
+
+use Moo;
+use namespace::autoclean;
 
 use Data::Validate::IP 0.19 qw( is_public_ipv4 is_public_ipv6 );
 use GeoIP2::Error::Generic;
@@ -29,8 +32,6 @@ use Sub::Quote qw( quote_sub );
 use Try::Tiny;
 use URI;
 
-use Moo;
-
 with 'GeoIP2::Role::HasLocales';
 
 has user_id => (
@@ -196,10 +197,10 @@ sub _handle_error_status {
         $self->_handle_4xx_status( $response, $status, $uri, $ip );
     }
     elsif ( $status =~ /^5/ ) {
-        $self->_handle_5xx_status( $response, $status, $uri );
+        $self->_handle_5xx_status( $status, $uri );
     }
     else {
-        $self->_handle_non_200_status( $response, $status, $uri );
+        $self->_handle_non_200_status( $status, $uri );
     }
 }
 
@@ -264,10 +265,9 @@ sub _handle_4xx_status {
 }
 
 sub _handle_5xx_status {
-    my $self     = shift;
-    my $response = shift;
-    my $status   = shift;
-    my $uri      = shift;
+    my $self   = shift;
+    my $status = shift;
+    my $uri    = shift;
 
     GeoIP2::Error::HTTP->throw(
         message     => "Received a server error ($status) for $uri",
@@ -277,10 +277,9 @@ sub _handle_5xx_status {
 }
 
 sub _handle_non_200_status {
-    my $self     = shift;
-    my $response = shift;
-    my $status   = shift;
-    my $uri      = shift;
+    my $self   = shift;
+    my $status = shift;
+    my $uri    = shift;
 
     GeoIP2::Error::HTTP->throw(
         message =>
@@ -310,13 +309,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 GeoIP2::WebService::Client - Perl API for the GeoIP2 Precision web services
 
 =head1 VERSION
 
-version 2.003002
+version 2.003003
 
 =head1 SYNOPSIS
 
@@ -549,6 +550,10 @@ the C<GeoIP2::Record::Traits> record.
 Every record class attribute has a corresponding predicate method so you can
 check to see if the attribute is set.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -573,7 +578,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2013 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
